"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CourseController = void 0;
const openapi = require("@nestjs/swagger");
const common_1 = require("@nestjs/common");
const platform_express_1 = require("@nestjs/platform-express");
const swagger_1 = require("@nestjs/swagger");
const course_schema_1 = require("../schemas/course.schema");
const course_service_1 = require("../services/course.service");
let CourseController = class CourseController {
    constructor(courseService) {
        this.courseService = courseService;
    }
    async getAllCourses() {
        return this.courseService.getAllCourses();
    }
    async findByOrganizationId(organizationId) {
        return this.courseService.getCoursesByOrganizationId(organizationId);
    }
    async getCourseById(courseId, studentId) {
        try {
            const course = await this.courseService.getCourseById(courseId, studentId);
            return course;
        }
        catch (error) {
            throw new common_1.HttpException('Failed to retrieve course', common_1.HttpStatus.INTERNAL_SERVER_ERROR);
        }
    }
    async findByStatus(status, courseType) {
        return this.courseService.getCoursesByStatusAndType(status, courseType);
    }
    async findByInstructorId(instructorId) {
        return this.courseService.getCoursesByInstructorId(instructorId);
    }
    async findByCourseByType(courseType) {
        return this.courseService.getCoursesByType(courseType);
    }
    async createCourse(thumbnail, course) {
        var _a;
        const existingCourse = await this.courseService.checkCourseNameExists(course.name);
        if (existingCourse) {
            throw new common_1.HttpException("Course already exists!", common_1.HttpStatus.FORBIDDEN);
        }
        if (thumbnail) {
            course.thumbnail = (_a = thumbnail === null || thumbnail === void 0 ? void 0 : thumbnail.buffer) === null || _a === void 0 ? void 0 : _a.toString("base64");
        }
        return this.courseService.create(course);
    }
    async editCourse(courseId, thumbnail, updatedCourse) {
        var _a;
        try {
            if (updatedCourse.thumbnail &&
                !updatedCourse.thumbnail.startsWith("https")) {
                if (thumbnail) {
                    updatedCourse.thumbnail = (_a = thumbnail === null || thumbnail === void 0 ? void 0 : thumbnail.buffer) === null || _a === void 0 ? void 0 : _a.toString("base64");
                }
            }
            return this.courseService.update(courseId, updatedCourse);
        }
        catch (error) {
            if (error instanceof common_1.NotFoundException) {
                throw new common_1.HttpException(`Course with ID ${courseId} not found`, common_1.HttpStatus.NOT_FOUND);
            }
            throw error;
        }
    }
    async deleteCourse(courseId) {
        try {
            await this.courseService.delete(courseId);
        }
        catch (error) {
            if (error instanceof common_1.NotFoundException) {
                throw new common_1.HttpException(`Course with ID ${courseId} not found`, common_1.HttpStatus.NOT_FOUND);
            }
            throw error;
        }
    }
};
__decorate([
    (0, common_1.Get)("get-all"),
    openapi.ApiResponse({ status: 200, type: [require("../schemas/course.schema").Course] }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], CourseController.prototype, "getAllCourses", null);
__decorate([
    (0, common_1.Get)("get-by-organization-id"),
    openapi.ApiResponse({ status: 200, type: [require("../schemas/course.schema").Course] }),
    __param(0, (0, common_1.Query)("organizationId")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], CourseController.prototype, "findByOrganizationId", null);
__decorate([
    (0, common_1.Get)("get-course-by-id"),
    openapi.ApiResponse({ status: 200, type: require("../schemas/course.schema").Course }),
    __param(0, (0, common_1.Query)("courseId")),
    __param(1, (0, common_1.Query)("studentId")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String]),
    __metadata("design:returntype", Promise)
], CourseController.prototype, "getCourseById", null);
__decorate([
    (0, common_1.Get)("get-by-status"),
    openapi.ApiResponse({ status: 200, type: [require("../schemas/course.schema").Course] }),
    __param(0, (0, common_1.Query)("status")),
    __param(1, (0, common_1.Query)("courseType")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String]),
    __metadata("design:returntype", Promise)
], CourseController.prototype, "findByStatus", null);
__decorate([
    (0, common_1.Get)("get-by-instructor-id"),
    openapi.ApiResponse({ status: 200, type: [require("../schemas/course.schema").Course] }),
    __param(0, (0, common_1.Query)("instructorId")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], CourseController.prototype, "findByInstructorId", null);
__decorate([
    (0, common_1.Get)("get-by-type"),
    openapi.ApiResponse({ status: 200, type: [require("../schemas/course.schema").Course] }),
    __param(0, (0, common_1.Query)("courseType")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], CourseController.prototype, "findByCourseByType", null);
__decorate([
    (0, common_1.Post)("create"),
    (0, common_1.UseInterceptors)((0, platform_express_1.FileInterceptor)("thumbnail")),
    openapi.ApiResponse({ status: 201, type: require("../schemas/course.schema").Course }),
    __param(0, (0, common_1.UploadedFile)()),
    __param(1, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, course_schema_1.Course]),
    __metadata("design:returntype", Promise)
], CourseController.prototype, "createCourse", null);
__decorate([
    (0, common_1.Put)("edit/:id"),
    (0, common_1.UseInterceptors)((0, platform_express_1.FileInterceptor)("thumbnail")),
    openapi.ApiResponse({ status: 200, type: require("../schemas/course.schema").Course }),
    __param(0, (0, common_1.Param)("id")),
    __param(1, (0, common_1.UploadedFile)()),
    __param(2, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Object, course_schema_1.Course]),
    __metadata("design:returntype", Promise)
], CourseController.prototype, "editCourse", null);
__decorate([
    (0, common_1.Delete)("delete/:id"),
    openapi.ApiResponse({ status: 200 }),
    __param(0, (0, common_1.Param)("id")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], CourseController.prototype, "deleteCourse", null);
CourseController = __decorate([
    (0, swagger_1.ApiTags)("Courses"),
    (0, common_1.Controller)("courses"),
    __metadata("design:paramtypes", [course_service_1.CourseService])
], CourseController);
exports.CourseController = CourseController;
//# sourceMappingURL=course.controller.js.map