"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AssignmentService = void 0;
const common_1 = require("@nestjs/common");
const mongoose_1 = require("@nestjs/mongoose");
const mongoose_2 = require("mongoose");
const assignment_schema_1 = require("../schemas/assignment.schema");
const cloudinary_service_1 = require("./cloudinary.service");
const stream_1 = require("stream");
let AssignmentService = class AssignmentService {
    constructor(assignmentModel, cloudinaryService) {
        this.assignmentModel = assignmentModel;
        this.cloudinaryService = cloudinaryService;
    }
    async create(assignment) {
        await this.checkAssignmentTextNotExists(assignment.assignmentName, assignment.lessonId);
        if (assignment.assignmentFile) {
            const thumbnailStream = new stream_1.Readable();
            thumbnailStream.push(Buffer.from(assignment.assignmentFile, "base64"));
            thumbnailStream.push(null);
            const thumbnailUrl = await this.cloudinaryService.uploadImage(thumbnailStream);
            assignment.assignmentFile = thumbnailUrl;
        }
        if (assignment.answerFile) {
            const thumbnailStream = new stream_1.Readable();
            thumbnailStream.push(Buffer.from(assignment.answerFile, "base64"));
            thumbnailStream.push(null);
            const thumbnailUrl = await this.cloudinaryService.uploadImage(thumbnailStream);
            assignment.answerFile = thumbnailUrl;
        }
        const createdAssignment = new this.assignmentModel(assignment);
        return createdAssignment.save();
    }
    async edit(assignmentId, updatedAssignment) {
        var _a, _b;
        await this.checkAssignmentTextNotExists(updatedAssignment.assignmentName, updatedAssignment.lessonId, assignmentId);
        if (updatedAssignment.assignmentFile &&
            !((_a = updatedAssignment.assignmentFile) === null || _a === void 0 ? void 0 : _a.startsWith("https"))) {
            const thumbnailStream = new stream_1.Readable();
            thumbnailStream.push(Buffer.from(updatedAssignment.assignmentFile, "base64"));
            thumbnailStream.push(null);
            const thumbnailUrl = await this.cloudinaryService.uploadImage(thumbnailStream);
            if (updatedAssignment.assignmentFile) {
                updatedAssignment.assignmentFile = thumbnailUrl;
            }
        }
        if (updatedAssignment.answerFile &&
            !((_b = updatedAssignment.answerFile) === null || _b === void 0 ? void 0 : _b.startsWith("https"))) {
            const thumbnailStream = new stream_1.Readable();
            thumbnailStream.push(Buffer.from(updatedAssignment.answerFile, "base64"));
            thumbnailStream.push(null);
            const thumbnailUrl = await this.cloudinaryService.uploadImage(thumbnailStream);
            if (updatedAssignment.answerFile) {
                updatedAssignment.answerFile = thumbnailUrl;
            }
        }
        const existingAssignment = await this.assignmentModel.findByIdAndUpdate(assignmentId, updatedAssignment, {
            new: true
        }).exec();
        if (!existingAssignment) {
            throw new common_1.NotFoundException(`Assignment with ID ${assignmentId} not found`);
        }
        return existingAssignment;
    }
    async findAll() {
        return this.assignmentModel.find().exec();
    }
    async findById(assignmentId) {
        const assignment = await this.assignmentModel.findById(assignmentId).exec();
        if (!assignment) {
            throw new common_1.NotFoundException(`Assignment with id ${assignmentId} not found`);
        }
        return assignment;
    }
    async findByLessonId(lessonId) {
        return this.assignmentModel.find({ lessonId }).exec();
    }
    async delete(assignmentId) {
        await this.findById(assignmentId);
        await this.assignmentModel.findByIdAndDelete(assignmentId).exec();
    }
    async deleteByLessonId(lessonId) {
        await this.assignmentModel.deleteMany({ lessonId }).exec();
    }
    async checkAssignmentTextNotExists(assignmentName, lessonId, excludedAssignmentId) {
        const existingAssignment = await this.assignmentModel
            .findOne({ assignmentName, lessonId, _id: { $ne: excludedAssignmentId } })
            .exec();
        if (existingAssignment) {
            throw new common_1.ConflictException(`Assignment "${assignmentName}" already exists for the given lesson`);
        }
    }
};
AssignmentService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, mongoose_1.InjectModel)(assignment_schema_1.Assignment.name)),
    __metadata("design:paramtypes", [mongoose_2.Model,
        cloudinary_service_1.CloudinaryService])
], AssignmentService);
exports.AssignmentService = AssignmentService;
//# sourceMappingURL=assignment.service.js.map