"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CourseDetailsService = void 0;
const common_1 = require("@nestjs/common");
const course_service_1 = require("./course.service");
const section_service_1 = require("./section.service");
const lesson_service_1 = require("./lesson.service");
const question_service_1 = require("./question.service");
const assignment_service_1 = require("./assignment.service");
const enrollments_service_1 = require("./enrollments.service");
const user_service_1 = require("./user.service");
let CourseDetailsService = class CourseDetailsService {
    constructor(courseService, sectionService, lessonService, questionService, assignmentService, enrollmentsService, userService) {
        this.courseService = courseService;
        this.sectionService = sectionService;
        this.lessonService = lessonService;
        this.questionService = questionService;
        this.assignmentService = assignmentService;
        this.enrollmentsService = enrollmentsService;
        this.userService = userService;
    }
    async getCourseDetails(courseId) {
        var _a, _b, _c, _d, _e;
        const course = await this.courseService.getCourseById(courseId);
        const sections = await this.sectionService.getByCourseId(courseId);
        const courseDetails = {
            id: ((_a = course === null || course === void 0 ? void 0 : course.course) === null || _a === void 0 ? void 0 : _a._id) || ((_b = course === null || course === void 0 ? void 0 : course.course) === null || _b === void 0 ? void 0 : _b.id),
            courseName: (_c = course === null || course === void 0 ? void 0 : course.course) === null || _c === void 0 ? void 0 : _c.name,
            organizationId: (_d = course === null || course === void 0 ? void 0 : course.course) === null || _d === void 0 ? void 0 : _d.organizationId,
            courseType: (_e = course === null || course === void 0 ? void 0 : course.course) === null || _e === void 0 ? void 0 : _e.courseType,
            sections: await Promise.all(sections.map(async (section) => {
                const lessons = await this.lessonService.getBySectionId(section.id);
                const sectionDetails = {
                    id: section._id,
                    name: section.name,
                    isActive: section.isActive,
                    positions: section.positions,
                    duration: section.duration,
                    courseId: section.courseId,
                    lessons: await Promise.all(lessons.map(async (lesson) => {
                        const lessonDetails = {
                            id: lesson._id,
                            name: lesson.name,
                            sectionId: lesson.sectionId,
                            sectionName: lesson.sectionName,
                            duration: lesson.duration,
                            lessonURL: lesson.lessonURL,
                            thumbnail: lesson.thumbnail,
                            isFree: lesson.isFree,
                            positions: lesson.positions,
                            isModelTest: lesson.isModelTest,
                            passingMarks: lesson.passingMarks,
                            examTime: lesson.examTime,
                            isNegativeMarks: lesson.isNegativeMarks,
                            negativeMarks: lesson.negativeMarks,
                            isActive: lesson.isActive,
                            info: lesson.info,
                            questions: await this.questionService.getByLessonId(lesson._id),
                            assignments: await this.assignmentService.findByLessonId(lesson._id),
                        };
                        return lessonDetails;
                    })),
                };
                return sectionDetails;
            })),
        };
        return courseDetails;
    }
    async getCourseWiseSection(courseId, studentId) {
        var _a, _b, _c, _d;
        const course = await this.courseService.getCourseById(courseId);
        const sections = await this.sectionService.getByCourseId(courseId);
        let enrollments;
        let student;
        if (studentId) {
            enrollments = await this.enrollmentsService.getByStudentAndCourseId(courseId, studentId);
            student = await this.userService.getById(studentId);
        }
        const isAuthUser = (((_a = course === null || course === void 0 ? void 0 : course.course) === null || _a === void 0 ? void 0 : _a.isFree) && (student === null || student === void 0 ? void 0 : student.name));
        const courseDetails = {
            id: (course === null || course === void 0 ? void 0 : course.course._id) || (course === null || course === void 0 ? void 0 : course.course.id),
            courseName: (_b = course === null || course === void 0 ? void 0 : course.course) === null || _b === void 0 ? void 0 : _b.name,
            isAuthUserCourse: isAuthUser ? true : (enrollments === null || enrollments === void 0 ? void 0 : enrollments.isAmountPaid) ? true : false,
            organizationId: (_c = course === null || course === void 0 ? void 0 : course.course) === null || _c === void 0 ? void 0 : _c.organizationId,
            courseType: (_d = course === null || course === void 0 ? void 0 : course.course) === null || _d === void 0 ? void 0 : _d.courseType,
            sections: await Promise.all(sections.map(async (section) => {
                const lessons = await this.lessonService.getSectionById(section.id);
                const sectionDetails = {
                    id: section._id,
                    name: section.name,
                    isActive: section.isActive,
                    positions: section.positions,
                    duration: section.duration,
                    isAuthUserCourse: isAuthUser ? true : (enrollments === null || enrollments === void 0 ? void 0 : enrollments.isAmountPaid) ? true : false,
                    courseId: section.courseId,
                    lessons: await Promise.all(lessons.map(async (lesson) => {
                        const lessonDetails = {
                            id: lesson._id,
                            name: lesson.name,
                            duration: lesson.duration,
                            lessonURL: lesson.lessonURL,
                            thumbnail: lesson.thumbnail,
                            isFree: lesson.isFree,
                            isAuthUser: isAuthUser ? true : (enrollments === null || enrollments === void 0 ? void 0 : enrollments.isAmountPaid) ? true : false,
                            positions: lesson.positions,
                            isModelTest: lesson.isModelTest,
                            isActive: lesson.isActive,
                        };
                        return lessonDetails;
                    })),
                };
                return sectionDetails;
            })),
        };
        return courseDetails;
    }
    async getLessonDetails(lessonId) {
        const lesson = await this.lessonService.getById(lessonId);
        if (!lesson) {
            throw new common_1.NotFoundException(`Lesson with ID ${lessonId} not found`);
        }
        const lessonDetails = {
            id: lesson._id,
            name: lesson.name,
            sectionId: lesson.sectionId,
            sectionName: lesson.sectionName,
            duration: lesson.duration,
            lessonURL: lesson.lessonURL,
            thumbnail: lesson.thumbnail,
            isFree: lesson.isFree,
            positions: lesson.positions,
            isModelTest: lesson.isModelTest,
            passingMarks: lesson.passingMarks || 0,
            examTime: lesson.examTime,
            isNegativeMarks: lesson.isNegativeMarks,
            negativeMarks: lesson.negativeMarks,
            markPerQuestion: lesson.markPerQuestion,
            isActive: lesson.isActive,
            info: lesson.info,
            questions: await this.questionService.getByLessonId(lesson._id),
            assignments: await this.assignmentService.findByLessonId(lesson._id),
        };
        return lessonDetails;
    }
    async deleteLessonWithQuestionsAssignment(lessonId) {
        const existingLesson = await this.lessonService.getById(lessonId);
        if (!existingLesson) {
            throw new common_1.NotFoundException(`Lesson with ID ${lessonId} not found`);
        }
        await this.questionService.deleteByLessonId(lessonId);
        await this.assignmentService.deleteByLessonId(lessonId);
        await this.lessonService.delete(lessonId);
    }
    async getCoursesSummary(courseType) {
        const totalCourse = await this.courseService.getTotalCourses(courseType);
        const totalLesson = await this.lessonService.getTotalLessons();
        const totalEnrollment = await this.enrollmentsService.getTotalEnrolments();
        const totalActiveCourse = await this.courseService.getTotalActiveCourses(courseType);
        const totalPendingCourse = await this.courseService.getTotalPendingCourses(courseType);
        const totalFreeCourse = await this.courseService.getTotalFreeCourses(courseType);
        const totalPaidCourse = await this.courseService.getTotalPaidCourses(courseType);
        return {
            totalCourse,
            totalLesson,
            totalEnrollment,
            totalStudent: totalEnrollment,
            totalActiveCourse,
            totalPendingCourse,
            totalFreeCourse,
            totalPaidCourse,
        };
    }
};
CourseDetailsService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [course_service_1.CourseService,
        section_service_1.SectionService,
        lesson_service_1.LessonService,
        question_service_1.QuestionService,
        assignment_service_1.AssignmentService,
        enrollments_service_1.EnrollmentsService,
        user_service_1.UserService])
], CourseDetailsService);
exports.CourseDetailsService = CourseDetailsService;
//# sourceMappingURL=courseDetails.service.js.map